DotGraph Module
Converters into GraphViz
Functions and values
| Function or value |
Description
|
Full Usage:
exportToDot (writeHeader, writeFooter, writeSpout, writeBolt, writeStream) writer topology
Parameters:
'a -> Topology<'b> -> unit
writeFooter : 'a -> Topology<'b> -> 'c
writeSpout : 'a -> ComponentId -> Spout<'b> -> unit
writeBolt : 'a -> ComponentId -> Bolt<'b> -> unit
writeStream : 'a -> StreamId * ComponentId -> Stream<'b> -> unit
writer : 'a
topology : Topology<'b>
Returns: 'c
Type parameters: 'a, 'b, 'c (requires :> System.IO.TextWriter) |
send the topology to a given writer in GraphViz DOT format
|
Full Usage:
getColour colours
Parameters:
string[]
Returns: string -> string
|
lookup a colour based on a stream id
|
Full Usage:
streamColours
Returns: string[]
|
X11 colours
|
Full Usage:
writeBolt writer id b
Parameters:
TextWriter
id : string
b : Bolt<'a>
Type parameters: 'a |
node statement for a bolt
|
Full Usage:
writeColourfulStream getColour writer (arg3, arg3) st
Parameters:
string -> string
writer : TextWriter
arg2 : 'a * string
arg3 : 'b
st : Stream<'c>
Type parameters: 'a, 'b, 'c |
colourized edge statement for a stream
|
|
put together default implementations with colour to write to STDOUT
|
Full Usage:
writeFooter writer arg2
Parameters:
TextWriter
arg1 : Topology<'a>
Type parameters: 'a |
closing graph statement
|
Full Usage:
writeHeader writer t
Parameters:
TextWriter
t : Topology<'a>
Type parameters: 'a |
opening graph statement
|
Full Usage:
writeSpout writer id s
Parameters:
TextWriter
id : string
s : Spout<'a>
Type parameters: 'a |
node statement for a spout
|
Full Usage:
writeStream writer (arg2, arg2) st
Parameters:
TextWriter
arg1 : 'a * string
arg2 : 'b
st : Stream<'c>
Type parameters: 'a, 'b, 'c |
edge statement for a stream
|
|
put together default implementations to write to STDOUT
|
FsShelter