Spout Module
Functions and values
| Function or value |
Description
|
|
|
define a reliable spout mkArgs: one-time construction of arguments that will be passed into each next() call. mkAcker: one time construction of `Ack*Nack` handlers (using the args). next: spout function that returns an id*tuple option.
|
|
|
define spout with no processing guarantees mkArgs: one-time construction of arguments that will be passed into each next() call. next: spout function that returns a tuple option.
|
FsShelter