Logo FsShelter

Nimbus Module

Nimbus client module

Functions and values

Function or value Description

DefaultPort

Full Usage: DefaultPort

Returns: int
Returns: int

kill nimbus name

Full Usage: kill nimbus name

Parameters:
    nimbus : Client
    name : string

Returns: Task

kill a running topology

nimbus : Client
name : string
Returns: Task

submit nimbus conf uploadedJarLocation (name, topology)

Full Usage: submit nimbus conf uploadedJarLocation (name, topology)

Parameters:
Returns: Task
Type parameters: 'a, 'b (requires comparison)

sumit a topology

nimbus : Client
conf : Map<'a, 'b>
uploadedJarLocation : string
name : string
topology : StormTopology
Returns: Task

uploadJar nimbus jarFile

Full Usage: uploadJar nimbus jarFile

Parameters:
    nimbus : Client
    jarFile : string

Returns: Task<string>

upload the packaged jar to Nimbus and return the location on the server

nimbus : Client
jarFile : string
Returns: Task<string>

withClient nimbusHost nimbusPort cont

Full Usage: withClient nimbusHost nimbusPort cont

Parameters:
    nimbusHost : string
    nimbusPort : int
    cont : Client -> Task

Returns: Task<unit>

establish Nimbus (a storm service) connection over thrift protocol and execute the passed action using it

nimbusHost : string
nimbusPort : int
cont : Client -> Task
Returns: Task<unit>

Type something to start searching.