SupervisorInput Type
External inputs the orchestrator feeds into the pure step function.
Union cases
| Union case |
Description
|
Full Usage:
ElectionUpdate(selfIsMaster, nowMs)
Parameters:
bool
nowMs : int64
|
Latest election decision after a membership change or tick.
|
Full Usage:
Shutdown
|
Caller invoked the Shutdown returned by `runCluster`. |
Full Usage:
StabilizeElapsed nowMs
Parameters:
int64
|
Stabilize timer fired at `nowMs`.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.IsElectionUpdate
Returns: bool
|
|
Full Usage:
this.IsShutdown
Returns: bool
|
|
Full Usage:
this.IsStabilizeElapsed
Returns: bool
|
|
FsShelter